DocumentBuilder

Struct DocumentBuilder 

pub struct DocumentBuilder { /* private fields */ }
Builder for constructing XML documents.

This is used internally by the parser but can also be used to programmatically build documents.

The builder avoids RwLock overhead during construction by storing nodes directly in a Vec. The lock is only created when build() is called.

Implementations

Source

impl DocumentBuilder

pub fn new() -> Self

Creates a new document builder.

pub fn start_element( &mut self, name: &str, prefix: Option<&str>, namespace_uri: Option<&str>, attributes: Vec<(&str, &str)>, namespace_decls: Vec<Namespace>, line: Option<usize>, column: Option<usize>, ) -> NodeId

Starts a new element.

pub fn end_element(&mut self)

Ends the current element.

pub fn text(&mut self, content: &str) -> NodeId

Adds a text node.

pub fn cdata(&mut self, content: &str) -> NodeId

Adds a CDATA node.

pub fn comment(&mut self, content: &str) -> NodeId

Adds a comment node.

pub fn processing_instruction( &mut self, target: &str, content: Option<&str>, ) -> NodeId

Adds a processing instruction.

pub fn build(self) -> XmlDocument

Finishes building and returns the document.