pub fn create_context(document: &XmlDocument) -> Result<XmlContext>Expand description
Creates an XPath context for a document.
The context automatically registers namespace bindings from the root element.
pub fn create_context(document: &XmlDocument) -> Result<XmlContext>Creates an XPath context for a document.
The context automatically registers namespace bindings from the root element.