FallbackMode

Enum FallbackMode 

pub enum FallbackMode {
    Disabled,
    Enabled,
}
Controls how non-streamable XPath expressions are handled.

By default, non-streamable XPath expressions will return an error. This prevents unexpected memory usage from automatic fallback to two-pass processing.

Variants



Disabled

Return an error for non-streamable XPath expressions (default).

Use this mode when you want to ensure streaming processing and avoid unexpected memory usage.



Enabled

Automatically use two-pass processing for non-streamable XPath.

Warning: This may load the entire document into memory. Only use this if you understand the memory implications.